import { scaleOrdinal } from 'd3';

const colorScale = scaleOrdinal()
	.domain(['apple', 'lemon'])
	.range(['#c11d1d', '#ebda42']);

const radiusScale = scaleOrdinal()
	.domain(['apple', 'lemon'])
	.range([45, 25]);



export const fruitsBowls = (selection, props) => {
  	const  {fruits, 
            height, 
            onHoverEquals, 
            selectedFruit
    } = props;
  
  	//general update-pattern for singular elements
  	const bowl = selection.selectAll('rect')
    		.data([null])
    		.enter().append('rect')
    				.attr('y',120)
    				.attr('width',600)
    				.attr('height',300)
    				.attr('rx',300/2);
  
  	const groups = selection.selectAll('g').data(fruits);
  	const groupsEnter = groups.enter().append('g');
  			
  	groupsEnter.merge(groups)
  			.attr('transform', (d, i) => `
						translate (${i * 100 + 60}, 
						${height / 2})`);
  
  	groups
      .exit().remove();
 
    groupsEnter
      .append('circle')
  		.merge(groups.select('circle'))
  			.attr('fill', d => colorScale(d.type))
  			.attr('stroke-width', 10)
  			.attr('stroke', d => 
             d.id === selectedFruit 
             ? 'black' 
             : 'none')
  			.attr('r', d => radiusScale(d.type))
  			.on('mouseover',d => onHoverEquals(d.id))
  			.on('mouseout',() => onHoverEquals(null));
  
  
  	groupsEnter
      .append('text')
  		.merge(groups.select('text'))
  			.text(d => d.type)
  			.attr('y', 120);
  
  	/*
  	const circlesDataJoin = selection.selectAll('circle').data(fruits, d => d.id);
  	
  	circlesDataJoin
      .enter().append('circle')
  			.attr('cx', (d, i) => i * 100 + 60)
  			.attr('cy', height / 2)
  			.attr('r', 0)
  		.merge(circlesDataJoin)
  			.attr('fill', d => colorScale(d.type))
  		.transition().duration(1000)
  			.attr('cx', (d, i) => i * 100 + 60)
  			.attr('r', d => radiusScale(d.type));
  
  
  	circlesDataJoin
      .exit()
  		.transition().duration(1000)
  			.attr('r', d => radiusScale(d.type))
      .remove();
		
  	const text = selection.selectAll('text').data(fruits, d => d.id);
  	
  	text
      .enter().append('text')
  			.attr('x', (d, i) => i * 100 + 60)
  			.attr('y', height / 2 + 140)
  		.merge(text)
  			.text(d => d.type)
  
  	text
      .exit().remove();
    */
    
};